# al-folio
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[core_contributors]: https://img.shields.io/badge/core_contributors-3-orange.svg 'Number of core contributors'
<!-- ALL-CONTRIBUTORS-BADGE:END -->
